<?php
namespace Claromentis\Core\DAL\MSSQL\NativeClient;

$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"] ?: array()) + array("_a591754a8ddcdbda9c80f1db4d91" . "1e14" => base64_decode("aXNfbn" . "VsbA=="), "_78aadcc2e8dfecef37e1fe6d5ffbcdb" . "b" => base64_decode("c3Fsc3J2X2ZldGNoX" . "2FycmF5"), "_d64c6254" . "864cf9665" . "6eabcea4c" . "48fe51" => base64_decode("c3Fsc3J2X2hhc1" . "9yb3dz"), "_020048b1b65987544bdb5f9afa6" . "92a0f" => base64_decode("TnVtUm93c" . "yBpcyBub3" . "Qgc3VwcG9" . "ydGVk"), "_9a1d01ea56101db475f6e198f" . "06a4f9d" => base64_decode("c3Fsc3J2X2ZyZWV" . "fc3RtdA=="));
use Claromentis\Core\DAL;
use UnsupportedOperationException;
class ResultUnbuffered implements DAL\ResultInterface
{
    protected $stmt;
    protected $has_data = null;
    
    
    public function __construct($_a606a2dcd236a549db0574a9c1675927)
    {
        $this->stmt = $_a606a2dcd236a549db0574a9c1675927;
        if ($_a606a2dcd236a549db0574a9c1675927 === true) {
            return;
        }
    }
    public function fetchRow()
    {
        $data = $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_78aadcc2e8df" . "ecef37e1fe6d5" . "ffbcdbb"]($this->stmt, SQLSRV_FETCH_NUMERIC);
        
        
        return $data;
    }
    public function fetchArray()
    {
        $data = $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_78aadcc2e8dfecef37e1fe6d5f" . "fbcdbb"]($this->stmt, SQLSRV_FETCH_ASSOC);
        
        
        return $data;
    }
    public function numRows()
    {
        throw new UnsupportedOperationException($GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_020048b1b6" . "5987544bdb5" . "f9afa692a0f"]);
        
        
        
    }
    public function hasData()
    {
        if ($GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_a591754" . "a8ddcdbd" . "a9c80f1d" . "b4d911e1" . "4"]($this->has_data)) {
            $this->has_data = $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_d64c6254864cf96656eabcea4c48fe5" . "1"]($this->stmt);
        }
        return $this->has_data;
    }
    public function free()
    {
        if ($this->stmt) {
            $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_9a1d01ea56101db475f6e198f06a" . "4f9d"]($this->stmt);
            $this->stmt = null;
        }
        return true;
    }
    
    
    
    
    
    
    
    public function fetchAllValues()
    {
        return DAL\DbUtil::fetchAllValues($this);
    }
    public function __destruct()
    {
        $this->free();
    }
}