<?php
$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] = (@$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] ?: array()) + array("_864872f3a7a1fb64f0e4" . "b39d54bd36a6" => base64_decode("U0VMRUNUIGlkIEZST00gcmJfZXZlbnRzIFdIRVJFIGlkPWludDppZCBPUiBwaWQ9aW50OmlkIE9SREVSIEJZIHRtcF9zdGFydC" . "BBU0M="), "_5846ddea7ff6d30bd0e7b" . "4a81710776e" => base64_decode("YXJyYXlfc2h" . "pZnQ="), "_c06c961f393742ecf" . "d52b72263ac9470" => base64_decode("aW50dm" . "Fs"), "_69ca75209" . "f57e94fd0b" . "b0d09e2ac2" . "60a" => base64_decode("U0VMRUNUIGlkIEZST00gY2xuX2V2ZW50IFd" . "IRVJFIHNlcV9pZCA9IGludDpzZXFfaWQ="), "_680336fd6e79305443cf7f46da1735" . "af" => base64_decode("IFdIRVJFIGlkID0" . "gaW50Omlk"), "_f628f13176918014775e95" . "3a0b1caad3" => base64_decode("U0VMRUNUIGlkLCBuYW1lLCBjbG5faWQsIGNyZWF0b3JfaWQsIHJvb21faWQsIGF0dF9saXN0X2lkLAoJCQlpc19wZXJzb25hbCwgdHosIGRlc2NyaXB0aW9uLCBsb2NhdGlvbiwgZGF0ZV9zdGFydCwgZGF0ZV9lbmQsIGZ1bGxfZGF5LAoJCQlyZXBldGl0aW9uX3N0cmluZywgY2xuX25vX2lj" . "YWwsIGlzX2ltcG9ydGVkLCBpY2FsX3VpZCBGUk9NIA=="), "_6438f0b6930a731c65" . "7363b00de4c1f5" => base64_decode("cmVwZXRpdGlv" . "bl9zdHJpbmc="), "_63aaf146dd9a5b0ee6a5d691" . "fa5569a7" => base64_decode("REVMRVRFIEZST00gY2xuX3NlcV9yZW1pbmRlciBXSEVSR" . "SBzZXFfaWQgPSBpbnQ6aWQ="), "_f771b8753f76" . "3af9d8a9600a0" . "f4b6f67" => base64_decode("REVMR" . "VRFIE" . "ZST00" . "g"), "_3b03f2d270ef2d368de" . "828f8858ca740" => base64_decode("U0VMRUNUIGNvbmZpcm1fc3RhdHVzIEZST00gY2xuX3NlcV9jb25maXJtIFdIRVJFIHNlcV9pZCA9IG" . "ludDppZCBBTkQgY29udGFjdF9pZCA9IGludDpjaWQ="), "_af9bd7d93485f6e2bf3a7436e0cbeed" . "7" => base64_decode("U0VMRUNUIGlkIEZST00gY2xuX2V2ZW50IFdIRVJFIHNlcV9pZCA9IGludDpzZXFfaWQgQU5EIHNlcV9j" . "aGFuZ2VkX2ZsYWcgPSAx"), "_62df08b6ed8667f8174a96d58970" . "883d" => base64_decode("aW50d" . "mFs"), "_84a9eb3b1aca2c6be317ab94c9c" . "bc1d7" => base64_decode("U0VMRUNUIGlkIEZST00gY2xuX2V2ZW50IFdIRVJFIHNlcV9pZCA9IGludDpzZXFfaWQgQU5EIGRhd" . "GVfc3RhcnQ+PWludDpzZCBBTkQgZGF0ZV9zdGFydDxpbnQ6ZWQ="), "_e2e360d42f9822dba7a4dd7" . "03002afb7" => base64_decode("c3RyOnJlcGV0aXRpb2" . "5fc3RyaW5n"), "_8bac72b3f79f86df502" . "33debc13d03a5" => base64_decode("REVMRVRFIEZST00gY2xuX3NlcV9jb" . "25maXJtIFdIRVJFIHNlcV9pZCA9IG" . "ludDppZA=="), "_ef3a72fcbe857b2afe45cb9d8" . "cafb253" => base64_decode("ZW" . "5k"), "_f88d69529b179470c2076" . "e0d0d403f14" => base64_decode("REVMRVRFIEZST00gY2xuX2F0dGVuZ" . "GVlcyBXSEVSRSBsaXN0X2lkID0gaW" . "50OmF0dF9saXN0X2lk"), "_710379c26e0ab906b3e255344a8f5d" . "29" => base64_decode("CgkJCVdIRVJFIGljYWxfdWlkPXN0cjp1aWQgQU5EIGNsbl9pZCA9IGludDpjaWQ" . "KCQkJT1JERVIgQlkgaWQgREVTQw=="), "_947967531816a9ca9bbe9" . "0eeb1abde98" => base64_decode("IFdIRVJFIG" . "lkPWludDpp" . "ZA=="), "_98352ba2863a6a18" . "384a186298815408" => base64_decode("U0VMRUNUIHJlbV90aW1lIEZST00gY2xuX3NlcV9yZW1pbmRlciB3aGVyZSB1c2VyX2lkID0gaW50On" . "VpZCBBTkQgc2VxX2lkID0gaW50OmVpZA=="), "_38f12d8b8c719a" . "8ce0fc2faefc225" . "f35" => base64_decode("YXJyY" . "XlfbW" . "Fw"), "_ccd9e402149a4aff4a20de1877" . "81aa41" => base64_decode("c3Rhc" . "nQ="), "_2c6b4c36d99957cced" . "50cb51f716d423" => base64_decode("RXZlbnQgbm90IGxv" . "YWRlZCE="), "_43fa09a4d" . "24696009b9" . "6d372edf5b" . "5c1" => base64_decode("cmVtX3RpbWU" . "="));
use Claromentis\Core\Services;






class CalendarEventSequence extends CalendarObject
{
    protected $is_critical_change = false;
    
    
    
    
    protected $table_name = 'cln_sequence';
    public $type = CALENDAR_TYPE_SEQUENCE;
    protected $aggregation = AGGREGATION_CLN_SEQUENCE;
    protected $repetition = '';
    
    
    
    
    
    
    protected $cached_child_event = false;
    protected $create_childs = true;
    public function __construct($_85eea3a16f7026a02992ff95eadc0eb1 = true)
    {
        $this->create_childs = $_85eea3a16f7026a02992ff95eadc0eb1;
        parent::__construct();
    }
    protected function GetLoadQuery()
    {
        return $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_f628f13176" . "918014775e9" . "53a0b1caad3"] . $this->table_name . $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_947967531816a9c" . "a9bbe90eeb1abde9" . "8"];
    }
    protected function GetLoadByUIDQuery()
    {
        return $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_f628f131769" . "18014775e953" . "a0b1caad3"] . $this->table_name . $GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_710379c26e0ab90" . "6b3e255344a8f5d2" . "9"];
    }
    
    
    
    
    
    
    
    
    
    protected function InitParametersByLoadArray($_343a395319323dd7609bcbc465b4d034)
    {
        if (!parent::InitParametersByLoadArray($_343a395319323dd7609bcbc465b4d034)) {
            return false;
        }
        $this->repetition = $_343a395319323dd7609bcbc465b4d034[$GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_6438f0b6930a731" . "c657363b00de4c1f" . "5"]];
        $this->period->LoadFromString($this->repetition);
        return true;
    }
    public function GetRepetition()
    {
        return $this->repetition;
    }
    
    
    
    
    
    
    
    public function CreatePropertiesArray()
    {
        return parent::CreatePropertiesArray() + array($GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_e2e360d42f9822dba7a4dd703002af" . "b7"] => $this->GetPeriod()->CreateSaveString());
    }
    
    
    
    
    
    
    public function Save()
    {
        $this->ValidateDates();
        if ($this->IsError()) {
            return false;
        }
        
        
        if ($this->GetId() > 0 && $this->IsCriticalChange()) {
            CalendarToolKit::DeleteCalendarObject($this, true, false, false, true);
            $this->attended_users = new CalendarEventUsers($this);
            $this->attended_contacts = new CalendarEventContacts($this);
            $this->id = 0;
        }
        return parent::Save();
    }
    protected function Update()
    {
        if (!parent::Update()) {
            return false;
        }
        $_9cee5807b5bab08d25cd4213e63cb764 = $this->GetChildrenIds();
        foreach ($_9cee5807b5bab08d25cd4213e63cb764 as $_0ea4e32b57963ac0cb3057e03e9aef64) {
            $event = new CalendarEvent();
            $event->Load($_0ea4e32b57963ac0cb3057e03e9aef64);
            if (!$event->GetSeqChangedFlag()) {
                $this->InitEventWithSequenceParameters($event);
                $event->Save();
            }
        }
        return true;
    }
    
    
    
    
    
    
    protected function GetBookingsArray()
    {
        global $db;
        return $db->query($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_864872f3a7a1fb64f0e4b39d54bd36" . "a6"], $this->GetBookingID(), $this->GetBookingID())->fetchAllValues();
    }
    protected function Insert()
    {
        $_7c7b8bf0e503161cad423a738d072ddf = array();
        if (!parent::Insert()) {
            return false;
        }
        $_f2a41580dce55e1aa803bb51249e43ca = $this->GetPeriod()->GetDatesArray(true);
        if ($this->GetBookingID() > 0) {
            $_7c7b8bf0e503161cad423a738d072ddf = $this->GetBookingsArray();
        }
        if ($this->create_childs) {
            foreach ((array) $_f2a41580dce55e1aa803bb51249e43ca as $_67a0d624aebcceb0abd5ce56a53ff06f) {
                $event = $this->CreateChildEvent($_67a0d624aebcceb0abd5ce56a53ff06f[$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_ccd9e402149a4aff4a" . "20de187781aa41"]], $_67a0d624aebcceb0abd5ce56a53ff06f[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_ef3a72fcbe857b2afe45cb9d8" . "cafb253"]], $this->GetPeriod()->IsFullDay());
                if ($_47f8df6f5aa7de674a0441d749522f0b = $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_5846ddea7ff6d30bd0e7b4a8171077" . "6e"]($_7c7b8bf0e503161cad423a738d072ddf)) {
                    $event->SetBookingId($_47f8df6f5aa7de674a0441d749522f0b);
                }
                $event->Save();
            }
        }
        return true;
    }
    
    
    
    
    
    
    
    protected function InitEventWithSequenceParameters(CalendarEvent $event)
    {
        $event->SetName($this->name);
        $event->SetClnId($this->cln_id);
        $event->SetCreatorId($this->creator_id);
        $event->SetDescription($this->description);
        $event->SetLocation($this->location);
        $event->SetPersonalMode($this->GetPersonalMode());
        $event->SetInitialTimezone($this->GetInitialTimezone());
        return $event;
    }
    
    
    
    
    
    
    
    
    
    protected function CreateChildEvent(Date $_ccd9e402149a4aff4a20de187781aa41, Date $_ef3a72fcbe857b2afe45cb9d8cafb253, $_62e32d5a92b034f6515d05dda6d7a62d)
    {
        if (!$this->cached_child_event) {
            $this->cached_child_event = $this->InitEventWithSequenceParameters(new CalendarEvent());
        }
        $event = clone $this->cached_child_event;
        $event->SetStartDate($_ccd9e402149a4aff4a20de187781aa41);
        $event->SetEndDate($_ef3a72fcbe857b2afe45cb9d8cafb253);
        $event->SetFullDay($GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_c06c961f393742ecfd52b72" . "263ac9470"]($_62e32d5a92b034f6515d05dda6d7a62d));
        $event->SetListId($this->list_id);
        $event->SetSeqId($this->id);
        $event->SetIsImported($this->is_imported);
        $event->SetICalUID($this->ical_uid);
        return $event;
    }
    public function _delete()
    {
        if (!$this->id) {
            return $this->SetErrMsg($GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_2c6b4c36d99957c" . "ced50cb51f716d42" . "3"]);
        }
        $db = Services::I()->GetDb();
        $db->query($GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_f88d695" . "29b17947" . "0c2076e0" . "d0d403f1" . "4"], $this->GetListId());
        $db->query($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_8bac72b3" . "f79f86df5" . "0233debc1" . "3d03a5"], $this->id);
        $db->query($GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_63aaf146dd9a5b0ee6" . "a5d691fa5569a7"], $this->id);
        $db->query($GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_f771b8753f7" . "63af9d8a9600" . "a0f4b6f67"] . $this->table_name . $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_680336f" . "d6e79305" . "443cf7f4" . "6da1735a" . "f"], $this->id);
        return true;
    }
    
    
    
    
    
    
    
    
    public function PrepareChildForDelete(CalendarEvent $event)
    {
        if ($event->GetListId() == $this->GetListId()) {
            $event->SetListId(0);
        }
        return true;
    }
    
    
    
    
    
    
    public function GetChildrenIds() : array
    {
        $_b2eee0013224d2924db36c4231aa5a1a = $this->GetId();
        if (empty($_b2eee0013224d2924db36c4231aa5a1a)) {
            return [];
        }
        $db = Services::I()->GetDb();
        return $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_38f12d8b8c71" . "9a8ce0fc2faef" . "c225f35"]($GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_62df08b6ed8667f817" . "4a96d58970883d"], $db->query($GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_69ca75209f57e94fd0" . "bb0d09e2ac260a"], $_b2eee0013224d2924db36c4231aa5a1a)->fetchAllValues());
    }
    public static function GetChildrenByStartDate($_b2eee0013224d2924db36c4231aa5a1a, Date $_91d10773c15d92f509551b22650c8a4e, $_f91e5675e763b68af3f9c9f9702b1d37 = null)
    {
        if (empty($_b2eee0013224d2924db36c4231aa5a1a)) {
            return 0;
        }
        $_2dda4556e52a6eb3aefc6ead58db909d = clone $_91d10773c15d92f509551b22650c8a4e;
        $_2dda4556e52a6eb3aefc6ead58db909d->setHour(0);
        $_2dda4556e52a6eb3aefc6ead58db909d->setMinute(0);
        $_2dda4556e52a6eb3aefc6ead58db909d->setSecond(0);
        $_1593021faad6b6b75f0d0b54a1ce58d3 = clone $_91d10773c15d92f509551b22650c8a4e;
        $_1593021faad6b6b75f0d0b54a1ce58d3->addDays(1);
        $db = Services::I()->GetDb();
        $_189840d11056515e52402d1412a0b6e4 = $db->query($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_84a9eb3b1aca2c6be317ab94c9" . "cbc1d7"], $_b2eee0013224d2924db36c4231aa5a1a, $_2dda4556e52a6eb3aefc6ead58db909d->getDate(), $_1593021faad6b6b75f0d0b54a1ce58d3->getDate());
        $_b8cfc2e06d9d1fec1893ea4a054002bf = $_189840d11056515e52402d1412a0b6e4->fetchRow();
        return (int) $_b8cfc2e06d9d1fec1893ea4a054002bf[0];
    }
    
    
    
    
    
    
    public function hasModifiedChildren()
    {
        if (empty($this->id)) {
            return false;
        }
        $db = Services::I()->GetDb();
        return $db->query($GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_af9bd7d93485f6e2bf3a" . "7436e0cbeed7"], $this->GetId())->hasData();
    }
    public function GetContactConfirmStatus($_29323189a19d68cee9551201fa097a55)
    {
        $_d88b50ddb42db648a9c7ac08065b9409 = $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_3b03f2d270" . "ef2d368de82" . "8f8858ca740"];
        return $this->GetContactConfirmStatusByQuery($_29323189a19d68cee9551201fa097a55, $_d88b50ddb42db648a9c7ac08065b9409);
    }
    
    
    
    
    
    
    
    public function SetCriticalChange($_601a171d59986f7c15972b586685671b)
    {
        $this->is_critical_change = $_601a171d59986f7c15972b586685671b;
    }
    
    
    
    
    
    
    
    public function IsCriticalChange()
    {
        return $this->is_critical_change;
    }
    public function GetReminder(?int $user_id = null) : ?int
    {
        if (empty($this->GetId())) {
            return null;
        }
        $db = Services::I()->GetDb();
        $user_id = $user_id ?? CalendarToolKit::Instance()->curr_user_settings->GetUserId();
        $_189840d11056515e52402d1412a0b6e4 = $db->query($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_98352ba2863" . "a6a18384a186" . "298815408"], $user_id, $this->GetId());
        if (!$_189840d11056515e52402d1412a0b6e4->hasData()) {
            return null;
        }
        $_343a395319323dd7609bcbc465b4d034 = $_189840d11056515e52402d1412a0b6e4->fetchArray();
        return $_343a395319323dd7609bcbc465b4d034[$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_43fa09a4d24696009b96d372edf5b5" . "c1"]];
    }
}